@@ -2,7 +2,6 @@
 
 import os
 
-from guniflask_cli.utils import pid_exists, read_pid
 from guniflask_cli.gunicorn import GunicornApplication
 from .base import Command
 
@@ -30,9 +29,4 @@ class Start(Command):
         app = GunicornApplication()
         if args.daemon_off:
             app.set_option('daemon', False)
-        pid = read_pid(app.options.get('pidfile'))
-        if pid is not None and pid_exists(pid):
-            print('Application is already started')
-            self.exitcode = 1
-        else:
-            app.run()
+        app.run()
