@@ -5,7 +5,6 @@ import sys
 from os.path import join, isfile, isdir
 import re
 import json
-import getpass
 
 __all__ = ['set_default_env', 'infer_project_name', 'get_project_name_from_env']
 
@@ -27,8 +26,6 @@ def set_default_env():
         os.environ['GUNIFLASK_LOG_DIR'] = join(home_dir, '.log')
     if not os.environ.get('GUNIFLASK_PID_DIR'):
         os.environ['GUNIFLASK_PID_DIR'] = join(home_dir, '.pid')
-    if not os.environ.get('GUNIFLASK_ID_STRING'):
-        os.environ['GUNIFLASK_ID_STRING'] = getpass.getuser()
 
 
 project_name_regex = re.compile(r'[a-zA-Z\-]+')
